@@ -12,11 +12,13 @@
 #include <config.h>
 #endif
 
+#include <stdlib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#if GLIB_CHECK_VERSION(2, 28, 0)
 #include <gio/gio.h>
-#endif
+
+#include <xfconf/xfconf.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "settings.h"
 #include "process-window.h"
@@ -24,9 +26,9 @@
 
 static XtmSettings *settings;
 static GtkWidget *window;
-static GtkStatusIcon *status_icon;
+static GtkStatusIcon *status_icon_or_null = NULL;
 static XtmTaskManager *task_manager;
-static guint timeout = 0;
+static guint timer_id;
 static gboolean start_hidden = FALSE;
 
 static GOptionEntry main_entries[] = {
@@ -64,19 +66,45 @@ status_icon_popup_menu (GtkStatusIcon *_status_icon, guint button, guint activat
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, gtk_status_icon_position_menu, _status_icon, button, activate_time);
 }
 
+static void
+create_status_icon (void)
+{
+	if (!status_icon_or_null)
+	{
+		GtkStatusIcon *status_icon = gtk_status_icon_new_from_icon_name ("org.xfce.taskmanager");
+		g_signal_connect (status_icon, "activate", G_CALLBACK (status_icon_activated), NULL);
+		g_signal_connect (status_icon, "popup-menu", G_CALLBACK (status_icon_popup_menu), NULL);
+		status_icon_or_null = status_icon;
+	}
+}
+
+static gboolean
+status_icon_get_visible (void)
+{
+	return status_icon_or_null && gtk_status_icon_get_visible (status_icon_or_null);
+}
+
 static void
 show_hide_status_icon (void)
 {
 	gboolean show_status_icon;
 	g_object_get (settings, "show-status-icon", &show_status_icon, NULL);
-	gtk_status_icon_set_visible (status_icon, show_status_icon);
+	if (show_status_icon)
+	{
+		create_status_icon ();
+		gtk_status_icon_set_visible (status_icon_or_null, TRUE);
+	}
+	else if (status_icon_get_visible ())
+	{
+		gtk_status_icon_set_visible (status_icon_or_null, FALSE);
+	}
 }
 
 static void
 destroy_window (void)
 {
 	if (gtk_main_level () > 0) {
-		xtm_settings_save_settings(settings);
+		xfconf_shutdown();
 		gtk_main_quit ();
 	}
 }
@@ -84,9 +112,9 @@ destroy_window (void)
 static gboolean
 delete_window (void)
 {
-	if (!gtk_status_icon_get_visible (status_icon))
+	if (!status_icon_get_visible ())
 	{
-		xtm_settings_save_settings(settings);
+		xfconf_shutdown();
 		gtk_main_quit ();
 		return FALSE;
 	}
@@ -94,8 +122,8 @@ delete_window (void)
 	return TRUE;
 }
 
-static gboolean
-init_timeout (void)
+static void
+collect_data (void)
 {
 	guint num_processes;
 	gfloat cpu, memory_percent, swap_percent;
@@ -124,7 +152,7 @@ init_timeout (void)
 	xtm_task_manager_get_swap_usage (task_manager, &swap_free, &swap_total);
 	xtm_process_window_show_swap_usage (XTM_PROCESS_WINDOW (window), (swap_total > 0));
 
-	if (gtk_status_icon_get_visible (status_icon))
+	if (status_icon_get_visible ())
 	{
 		g_snprintf (tooltip, sizeof(tooltip),
 				_("<b>Processes:</b> %u\n"
@@ -132,46 +160,46 @@ init_timeout (void)
 				"<b>Memory:</b> %s\n"
 				"<b>Swap:</b> %s"),
 				num_processes, cpu, memory_info, swap_info);
-		gtk_status_icon_set_tooltip_markup (GTK_STATUS_ICON (status_icon), tooltip);
+		gtk_status_icon_set_tooltip_markup (GTK_STATUS_ICON (status_icon_or_null), tooltip);
 	}
 
 	xtm_task_manager_update_model (task_manager);
+}
 
-	if (timeout == 0)
-	{
-		guint refresh_rate;
-		g_object_get (settings, "refresh-rate", &refresh_rate, NULL);
-		timeout = g_timeout_add (refresh_rate, (GSourceFunc)init_timeout, NULL);
-	}
-
+static gboolean
+init_timeout_cb (gpointer user_data)
+{
+	collect_data ();
 	return TRUE;
 }
 
 static void
-force_timeout_update (void)
+init_timeout (void)
 {
-	init_timeout ();
+	guint refresh_rate;
+
+	g_object_get (settings, "refresh-rate", &refresh_rate, NULL);
+	timer_id = g_timeout_add (refresh_rate, init_timeout_cb, NULL);
 }
 
 static void
 refresh_rate_changed (void)
 {
-	if (!g_source_remove (timeout))
+	if (!g_source_remove (timer_id))
 	{
 		g_critical ("Unable to remove source");
 		return;
 	}
-	timeout = 0;
+	timer_id = 0;
 	init_timeout ();
 }
 
 int main (int argc, char *argv[])
 {
-#if GLIB_CHECK_VERSION(2, 28, 0)
+	XfconfChannel *channel;
 	GApplication *app;
 	GError *error = NULL;
 	GOptionContext *opt_context;
-#endif
 #ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -181,7 +209,6 @@ int main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 	g_set_application_name (_("Task Manager"));
 
-#if GLIB_CHECK_VERSION(2, 28, 0)
 	opt_context = g_option_context_new ("");
 	g_option_context_add_main_entries (opt_context, main_entries, NULL);
 	g_option_context_add_group (opt_context, gtk_get_option_group (TRUE));
@@ -207,42 +234,49 @@ int main (int argc, char *argv[])
 		g_object_unref (app);
 		return 0;
 	}
-#endif
 
+	if (!xfconf_init (&error))
+	{
+		xfce_message_dialog (NULL, _("Xfce Notify Daemon"),
+			"dialog-error",
+			_("Settings daemon is unavailable"),
+			error->message,
+			"application-exit", GTK_RESPONSE_ACCEPT,
+			NULL);
+		exit (EXIT_FAILURE);
+	}
+
+	channel = xfconf_channel_new (CHANNEL);
 	settings = xtm_settings_get_default ();
-
-	status_icon = gtk_status_icon_new_from_icon_name ("org.xfce.taskmanager");
+	xtm_settings_bind_xfconf (settings, channel);
 	show_hide_status_icon ();
-	g_signal_connect (status_icon, "activate", G_CALLBACK (status_icon_activated), NULL);
-	g_signal_connect (status_icon, "popup-menu", G_CALLBACK (status_icon_popup_menu), NULL);
 
 	window = xtm_process_window_new ();
 
 	if (!start_hidden)
 		gtk_widget_show (window);
 
-#if GLIB_CHECK_VERSION(2, 28, 0)
 	g_signal_connect_swapped (app, "activate", G_CALLBACK (xtm_process_window_show), window);
-#endif
 
 	task_manager = xtm_task_manager_new (xtm_process_window_get_model (XTM_PROCESS_WINDOW (window)));
 
+	collect_data ();
 	init_timeout ();
 	g_signal_connect (settings, "notify::refresh-rate", G_CALLBACK (refresh_rate_changed), NULL);
-	g_signal_connect_after (settings, "notify::more-precision", G_CALLBACK (force_timeout_update), NULL);
-	g_signal_connect_after (settings, "notify::full-command-line", G_CALLBACK (force_timeout_update), NULL);
+	g_signal_connect_after (settings, "notify::more-precision", G_CALLBACK (collect_data), NULL);
+	g_signal_connect_after (settings, "notify::full-command-line", G_CALLBACK (collect_data), NULL);
 	g_signal_connect (settings, "notify::show-status-icon", G_CALLBACK (show_hide_status_icon), NULL);
 
 	g_signal_connect (window, "destroy", G_CALLBACK (destroy_window), NULL);
 	g_signal_connect (window, "delete-event", G_CALLBACK (delete_window), NULL);
 
-	if (gtk_widget_get_visible (window) || gtk_status_icon_get_visible (status_icon))
+	if (gtk_widget_get_visible (window) || status_icon_get_visible ())
 		gtk_main ();
 	else
 		g_warning ("Nothing to do: activate hiding to the notification area when using --start-hidden");
 
-	if (timeout > 0)
-		g_source_remove (timeout);
+	if (timer_id > 0)
+		g_source_remove (timer_id);
 
 	return 0;
 }
