@@ -24,23 +24,20 @@
 #include <X11/Xproto.h>
 
 #include <glib-object.h>
-#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <xfconf/xfconf.h>
+#include <libxfce4ui/libxfce4ui.h>
+
 #include "settings.h"
 #include "task-manager.h"
 #include "process-window.h"
-#if GTK_CHECK_VERSION(3, 0, 0)
-#include "process-window-gtk3_ui.h"
-#else
 #include "process-window_ui.h"
-#endif
 #include "process-monitor.h"
 #include "process-tree-view.h"
 #include "process-statusbar.h"
-#include "exec-tool-button.h"
-#include "settings-tool-button.h"
+#include "settings-dialog.h"
 
 
 
@@ -49,22 +46,26 @@ struct _XtmProcessWindowClass
 {
 	GtkWidgetClass		parent_class;
 };
+
 struct _XtmProcessWindow
 {
 	GtkWidget		parent;
 	/*<private>*/
 	GtkBuilder *		builder;
 	GtkWidget *		window;
-	GtkWidget *		toolbar;
 	GtkWidget *		filter_entry;
+	GtkWidget *		filter_searchbar;
 	GtkWidget *		cpu_monitor;
 	GtkWidget *		mem_monitor;
 	GtkWidget *		vpaned;
 	GtkWidget *		treeview;
 	GtkWidget *		statusbar;
-	GtkWidget *		exec_button;
 	GtkWidget *		settings_button;
 	XtmSettings *		settings;
+	XfconfChannel *		channel;
+	gint			width;
+	gint			height;
+	gulong			handler;
 };
 G_DEFINE_TYPE (XtmProcessWindow, xtm_process_window, GTK_TYPE_WIDGET)
 
@@ -72,12 +73,8 @@ static void	xtm_process_window_finalize			(GObject *object);
 static void	xtm_process_window_hide				(GtkWidget *widget);
 
 static void	emit_destroy_signal				(XtmProcessWindow *window);
-static gboolean	xtm_process_window_configure_event		(XtmProcessWindow *window, GdkEvent *event);
-static gboolean	xtm_process_vpaned_move_event			(XtmProcessWindow *window, GdkEventButton *event);
 static gboolean xtm_process_window_key_pressed	(XtmProcessWindow *window, GdkEventKey *event);
-static void	toolbar_update_style				(XtmProcessWindow *window);
 static void	monitor_update_step_size			(XtmProcessWindow *window);
-static void	show_about_dialog				(XtmProcessWindow *window);
 
 
 static void
@@ -88,7 +85,7 @@ filter_entry_icon_pressed_cb (GtkEntry *entry,
 {
 	if (position == GTK_ENTRY_ICON_SECONDARY) {
 		gtk_entry_set_text (entry, "");
-		gtk_widget_grab_focus(GTK_WIDGET(entry));
+		gtk_widget_grab_focus (GTK_WIDGET(entry));
 	}
 }
 
@@ -214,77 +211,88 @@ xtm_process_window_class_init (XtmProcessWindowClass *klass)
 }
 
 static void
-xtm_show_legend (XtmProcessWindow *window)
+xtm_process_window_size_allocate (GtkWidget *widget, GtkAllocation *allocation, gpointer user_data)
 {
-	gboolean show_legend;
+	XtmProcessWindow *window = (XtmProcessWindow *) user_data;
 
-	g_object_get (window->settings,
-				  "show-legend", &show_legend,
-				  NULL);
-	gtk_widget_set_visible (GTK_WIDGET (gtk_builder_get_object (window->builder, "legend")), show_legend);
+	g_return_if_fail (GTK_IS_WINDOW (XTM_PROCESS_WINDOW (widget)->window));
+
+	gtk_window_get_size (GTK_WINDOW (XTM_PROCESS_WINDOW (widget)->window), &window->width, &window->height);
+}
+
+static gboolean
+xtm_process_window_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+	XtmProcessWindow *window = (XtmProcessWindow *) user_data;
+
+	xfconf_channel_set_int (XTM_PROCESS_WINDOW (widget)->channel, SETTING_WINDOW_WIDTH, window->width);
+	xfconf_channel_set_int (XTM_PROCESS_WINDOW (widget)->channel, SETTING_WINDOW_HEIGHT, window->height);
+
+	return FALSE;
+}
+
+static void
+show_settings_dialog (GtkButton *button, gpointer user_data)
+{
+	XtmProcessWindow *window = (XtmProcessWindow *) user_data;
+
+	g_signal_handler_block (G_OBJECT (window->window), window->handler);
+	xtm_settings_dialog_run (window->window);
+	g_signal_handler_unblock (G_OBJECT (window->window), window->handler);
 }
 
 static void
 xtm_process_window_init (XtmProcessWindow *window)
 {
 	GtkWidget *button;
-	GtkWidget *icon;
-	GtkToolItem *xwininfo;
-	gint width, height;
-	gboolean show_legend;
+	gboolean active;
 
 	window->settings = xtm_settings_get_default ();
+	window->channel = xfconf_channel_new (CHANNEL);
 
 	window->builder = gtk_builder_new ();
 	gtk_builder_add_from_string (window->builder, process_window_ui, process_window_ui_length, NULL);
 
 	window->window = GTK_WIDGET (gtk_builder_get_object (window->builder, "process-window"));
-	g_object_get (window->settings, "window-width", &width, "window-height", &height, NULL);
-	if (width >= 1 && height >= 1)
-		gtk_window_resize (GTK_WINDOW (window->window), width, height);
+	window->width = xfconf_channel_get_int (window->channel, SETTING_WINDOW_WIDTH, DEFAULT_WINDOW_WIDTH);
+	window->height = xfconf_channel_get_int (window->channel, SETTING_WINDOW_HEIGHT, DEFAULT_WINDOW_HEIGHT);
+	if (window->width >= 1 && window->height >= 1)
+		gtk_window_set_default_size (GTK_WINDOW (window->window), window->width, window->height);
+
 	g_signal_connect_swapped (window->window, "destroy", G_CALLBACK (emit_destroy_signal), window);
+	window->handler = g_signal_connect_swapped (window->window, "size-allocate", G_CALLBACK (xtm_process_window_size_allocate), window);
+	g_signal_connect_swapped (window->window, "delete-event", G_CALLBACK (xtm_process_window_delete_event), window);
 	g_signal_connect_swapped (window->window, "key-press-event", G_CALLBACK(xtm_process_window_key_pressed), window);
-	g_signal_connect_swapped(window->window, "configure-event",
-	    G_CALLBACK(xtm_process_window_configure_event), window);
 
-	window->toolbar = GTK_WIDGET (gtk_builder_get_object (window->builder, "process-toolbar"));
-	g_signal_connect_swapped (window->settings, "notify::toolbar-style", G_CALLBACK (toolbar_update_style), window);
-	g_object_notify (G_OBJECT (window->settings), "toolbar-style");
+	button = GTK_WIDGET (gtk_builder_get_object (window->builder, "button-settings"));
+	g_signal_connect (G_OBJECT (button), "clicked",
+										G_CALLBACK (show_settings_dialog), window);
 
-	window->exec_button = xtm_exec_tool_button_new ();
-	gtk_toolbar_insert (GTK_TOOLBAR (window->toolbar), GTK_TOOL_ITEM (window->exec_button), 0);
-
-	window->settings_button = xtm_settings_tool_button_new ();
-	gtk_toolbar_insert (GTK_TOOLBAR (window->toolbar), GTK_TOOL_ITEM (window->settings_button), 1);
-	g_signal_connect_swapped (window->settings, "notify::show-legend", G_CALLBACK (xtm_show_legend), window);
-	g_object_notify (G_OBJECT (window->settings), "show-legend");
-
-	icon = gtk_image_new_from_icon_name ("xc_crosshair", GTK_ICON_SIZE_LARGE_TOOLBAR);
-	xwininfo = gtk_tool_button_new (icon, _("Identify Window"));
-	gtk_widget_set_tooltip_text (GTK_WIDGET (xwininfo), _("Identify an open window by clicking on it."));
-	gtk_toolbar_insert (GTK_TOOLBAR (window->toolbar), GTK_TOOL_ITEM (xwininfo), 2);
-	g_signal_connect (G_OBJECT (xwininfo), "clicked",
+	button = GTK_WIDGET (gtk_builder_get_object (window->builder, "button-identify"));
+	g_signal_connect (G_OBJECT (button), "clicked",
 										G_CALLBACK (xwininfo_clicked_cb), window);
-	gtk_widget_show_all (GTK_WIDGET (xwininfo));
 
-	button = GTK_WIDGET (gtk_builder_get_object (window->builder, "toolbutton-about"));
-	g_signal_connect_swapped (button, "clicked", G_CALLBACK (show_about_dialog), window);
+	window->filter_searchbar = GTK_WIDGET (gtk_builder_get_object (window->builder, "filter-searchbar"));
+	button = GTK_WIDGET (gtk_builder_get_object (window->builder, "button-show-filter"));
+	xfconf_g_property_bind (window->channel, SETTING_SHOW_FILTER, G_TYPE_BOOLEAN,
+		G_OBJECT (button), "active");
+	active = xfconf_channel_get_bool (window->channel, SETTING_SHOW_FILTER, FALSE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), active);
+	gtk_revealer_set_reveal_child (GTK_REVEALER (gtk_bin_get_child (GTK_BIN (window->filter_searchbar))), active);
+	g_object_bind_property (G_OBJECT (gtk_bin_get_child (GTK_BIN (window->filter_searchbar))), "reveal-child",
+													G_OBJECT (button), "active", G_BINDING_BIDIRECTIONAL);
 
 	{
 		GtkWidget *toolitem;
 		guint refresh_rate;
-		gint handle_position;
 
 		g_object_get (window->settings,
 					  "refresh-rate", &refresh_rate,
-					  "handle-position", &handle_position,
 					  NULL);
 
 		window->vpaned = GTK_WIDGET (gtk_builder_get_object (window->builder, "mainview-vpaned"));
-		if (handle_position > -1)
-			gtk_paned_set_position (GTK_PANED (window->vpaned), handle_position);
-		g_signal_connect_swapped(window->vpaned, "button-release-event",
-		    G_CALLBACK(xtm_process_vpaned_move_event), window);
+		xfconf_g_property_bind (window->channel, SETTING_HANDLE_POSITION, G_TYPE_INT,
+			G_OBJECT (window->vpaned), "position");
 
 		toolitem = GTK_WIDGET (gtk_builder_get_object (window->builder, "graph-cpu"));
 		window->cpu_monitor = xtm_process_monitor_new ();
@@ -307,34 +315,14 @@ xtm_process_window_init (XtmProcessWindow *window)
 	gtk_widget_show (window->statusbar);
 	gtk_box_pack_start (GTK_BOX (gtk_builder_get_object (window->builder, "graph-vbox")), window->statusbar, FALSE, FALSE, 0);
 
-	if (geteuid () == 0)
-	{
-#if GTK_CHECK_VERSION(3, 0, 0)
-		GtkCssProvider *css_provider;
-		css_provider = gtk_css_provider_new ();
-		gtk_css_provider_load_from_data (css_provider,
-										"#root-warning { background-color: #e53935; color: #ffffff; }",
-										-1, NULL);
-		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (css_provider),
-                                               GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-		g_object_unref (css_provider);
-#else
-		gtk_rc_parse_string ("style\"root-warning-style\"{bg[NORMAL]=\"#e53935\"\nfg[NORMAL]=\"#ffffff\"}\n"
-				"widget\"GtkWindow.*.root-warning\"style\"root-warning-style\"\n"
-				"widget\"GtkWindow.*.root-warning.GtkLabel\"style\"root-warning-style\"");
-#endif
-		gtk_widget_set_name (GTK_WIDGET (gtk_builder_get_object (window->builder, "root-warning-ebox")), "root-warning");
-		gtk_widget_show_all (GTK_WIDGET (gtk_builder_get_object (window->builder, "root-warning-box")));
-	}
+	gtk_widget_set_visible (GTK_WIDGET (gtk_builder_get_object (window->builder, "root-warning-box")), geteuid () == 0);
 
 	window->treeview = xtm_process_tree_view_new ();
 	gtk_widget_show (window->treeview);
 	gtk_container_add (GTK_CONTAINER (gtk_builder_get_object (window->builder, "scrolledwindow")), window->treeview);
 
-	g_object_get (window->settings,
-				  "show-legend", &show_legend,
-				  NULL);
-	gtk_widget_set_visible (GTK_WIDGET (gtk_builder_get_object (window->builder, "legend")), show_legend);
+	g_object_bind_property (gtk_builder_get_object (window->builder, "legend"), "visible",
+			window->settings, "show-legend", G_BINDING_BIDIRECTIONAL);
 
 	window->filter_entry = GTK_WIDGET(gtk_builder_get_object (window->builder, "filter-entry"));
 	g_signal_connect (G_OBJECT(window->filter_entry), "icon-press", G_CALLBACK(filter_entry_icon_pressed_cb), NULL);
@@ -355,12 +343,6 @@ xtm_process_window_finalize (GObject *object)
 	if (GTK_IS_BOX (window->statusbar))
 		gtk_widget_destroy (window->statusbar);
 
-	if (GTK_IS_TOOL_ITEM (window->exec_button))
-		gtk_widget_destroy (window->exec_button);
-
-	if (GTK_IS_TOOL_ITEM (window->settings_button))
-		gtk_widget_destroy (window->settings_button);
-
 	if (XTM_IS_SETTINGS (window->settings))
 		g_object_unref (window->settings);
 
@@ -378,85 +360,35 @@ emit_destroy_signal (XtmProcessWindow *window)
 	g_signal_emit_by_name (window, "destroy", G_TYPE_NONE);
 }
 
-static gboolean
-xtm_process_window_configure_event(XtmProcessWindow *window,
-    GdkEvent *event) {
-
-	if (NULL != window &&
-	    NULL != event && GDK_CONFIGURE == event->configure.type) {
-		g_object_set (window->settings,
-		    "window-width", event->configure.width,
-		    "window-height", event->configure.height,
-		    NULL);
-	}
-
-	return (FALSE);
-}
-
-static gboolean
-xtm_process_vpaned_move_event(XtmProcessWindow *window,
-    GdkEventButton *event __unused) {
-	gint handle_position;
-
-	if (NULL != window) {
-		handle_position = gtk_paned_get_position(GTK_PANED(window->vpaned));
-		g_object_set (window->settings,
-		    "handle-position", handle_position,
-		    NULL);
-	}
-
-	return (FALSE);
-}
-
 static gboolean
 xtm_process_window_key_pressed (XtmProcessWindow *window, GdkEventKey *event)
 {
 	gboolean ret = FALSE;
 
-	if (event->keyval == GDK_KEY_Escape ||
-		(event->keyval == GDK_KEY_q && (event->state & GDK_CONTROL_MASK))) {
-		xtm_settings_save_settings (window->settings);
+	if (event->keyval == GDK_KEY_Escape &&
+			gtk_widget_is_focus(GTK_WIDGET (window->filter_entry)))
+	{
+		if (xfconf_channel_get_bool (window->channel, SETTING_SHOW_FILTER, FALSE))
+			gtk_entry_set_text (GTK_ENTRY(window->filter_entry), "");
+		else
+			g_signal_emit_by_name (window, "delete-event", event, &ret, G_TYPE_BOOLEAN);
+	}
+	else if (event->keyval == GDK_KEY_Escape ||
+		(event->keyval == GDK_KEY_q && (event->state & GDK_CONTROL_MASK)))
+	{
 		g_signal_emit_by_name (window, "delete-event", event, &ret, G_TYPE_BOOLEAN);
 		ret = TRUE;
 	}
-	else if (event->keyval == GDK_KEY_f && (event->state & GDK_CONTROL_MASK)) {
+	else if (event->keyval == GDK_KEY_f && (event->state & GDK_CONTROL_MASK))
+	{
 		gtk_widget_grab_focus (GTK_WIDGET(window->filter_entry));
+		xfconf_channel_set_bool (window->channel, SETTING_SHOW_FILTER, TRUE);
 		ret = TRUE;
 	}
 
 	return ret;
 }
 
-static void
-toolbar_update_style (XtmProcessWindow *window)
-{
-	XtmToolbarStyle toolbar_style;
-	g_object_get (window->settings, "toolbar-style", &toolbar_style, NULL);
-	switch (toolbar_style)
-	{
-		default:
-		case XTM_TOOLBAR_STYLE_DEFAULT:
-		gtk_toolbar_set_icon_size (GTK_TOOLBAR (window->toolbar), GTK_ICON_SIZE_MENU);
-		gtk_toolbar_unset_style (GTK_TOOLBAR (window->toolbar));
-		break;
-
-		case XTM_TOOLBAR_STYLE_SMALL:
-		gtk_toolbar_set_icon_size (GTK_TOOLBAR (window->toolbar), GTK_ICON_SIZE_SMALL_TOOLBAR);
-		gtk_toolbar_set_style (GTK_TOOLBAR (window->toolbar), GTK_TOOLBAR_ICONS);
-		break;
-
-		case XTM_TOOLBAR_STYLE_LARGE:
-		gtk_toolbar_set_icon_size (GTK_TOOLBAR (window->toolbar), GTK_ICON_SIZE_LARGE_TOOLBAR);
-		gtk_toolbar_set_style (GTK_TOOLBAR (window->toolbar), GTK_TOOLBAR_ICONS);
-		break;
-
-		case XTM_TOOLBAR_STYLE_TEXT:
-		gtk_toolbar_set_icon_size (GTK_TOOLBAR (window->toolbar), GTK_ICON_SIZE_MENU);
-		gtk_toolbar_set_style (GTK_TOOLBAR (window->toolbar), GTK_TOOLBAR_BOTH);
-		break;
-	}
-}
-
 static void
 monitor_update_step_size (XtmProcessWindow *window)
 {
@@ -466,77 +398,6 @@ monitor_update_step_size (XtmProcessWindow *window)
 	g_object_set (window->mem_monitor, "step-size", refresh_rate / 1000.0, NULL);
 }
 
-#if !GTK_CHECK_VERSION(2,18,0)
-static void
-url_hook_about_dialog (GtkAboutDialog *dialog, const gchar *uri, gpointer user_data)
-{
-	gchar *command = g_strdup_printf ("exo-open %s", uri);
-	if (!g_spawn_command_line_async (command, NULL))
-	{
-		g_free (command);
-		command = g_strdup_printf ("firefox %s", uri);
-		g_spawn_command_line_async (command, NULL);
-	}
-	g_free (command);
-}
-#endif
-
-static void
-show_about_dialog (XtmProcessWindow *window)
-{
-	const gchar *authors[] = {
-		"(c) 2018-2019 Rozhuk Ivan",
-		"(c) 2014 Landry Breuil",
-		"(c) 2014 Harald Judt",
-		"(c) 2014 Peter de Ridder",
-		"(c) 2014 Simon Steinbess",
-		"(c) 2008-2010 Mike Massonnet",
-		"(c) 2005-2008 Johannes Zellner",
-		"",
-		"FreeBSD",
-		"  \342\200\242 Rozhuk Ivan",
-		"  \342\200\242 Mike Massonnet",
-		"  \342\200\242 Oliver Lehmann",
-		"",
-		"OpenBSD",
-		"  \342\200\242 Landry Breuil",
-		"",
-		"Linux",
-		"  \342\200\242 Johannes Zellner",
-		"  \342\200\242 Mike Massonnet",
-		"",
-		"OpenSolaris",
-		"  \342\200\242 Mike Massonnet",
-		"  \342\200\242 Peter Tribble",
-		NULL };
-	const gchar *license =
-		"This program is free software; you can redistribute it and/or modify\n"
-		"it under the terms of the GNU General Public License as published by\n"
-		"the Free Software Foundation; either version 2 of the License, or\n"
-		"(at your option) any later version.\n";
-
-#if !GTK_CHECK_VERSION(2,18,0)
-	gtk_about_dialog_set_url_hook (url_hook_about_dialog, NULL, NULL);
-#endif
-	gtk_show_about_dialog (GTK_WINDOW (window->window),
-		"program-name", _("Task Manager"),
-		"version", PACKAGE_VERSION,
-		"copyright", "Copyright \302\251 2005-2019 The Xfce development team",
-		"logo-icon-name", "utilities-system-monitor",
-#if !GTK_CHECK_VERSION(3, 0, 0)
-		"icon-name", GTK_STOCK_ABOUT,
-#endif
-		"comments", _("Easy to use task manager"),
-		"license", license,
-		"authors", authors,
-		"translator-credits", _("translator-credits"),
-		"website", "http://goodies.xfce.org/projects/applications/xfce4-taskmanager",
-		"website-label", "goodies.xfce.org",
-		NULL);
-}
-
-
-
 /**
  * Class functions
  */
